# -*- coding: utf-8 -*-
__title__ = u'django-flexisettings'
# semantic versioning, check http://semver.org/
__version__ = u'0.2.5'
__author__ = u'Stefan Berder <stefan.berder@ledapei.com>'
__copyright__ = u'Copyright 2012-2013, Heatwave fashion Ltd., ' \
    u'all rights reserved'
